@@ -12,3 +12,7 @@ pub const BCM_CHANGE_BRIGHTNESS_EVENT_CODE: u16 = 0x0006;
 
 pub const BUTTON_PRESSED_EVENT_CODE: u16 = 0x0007;
 pub const BUTTON_RELEASED_EVENT_CODE: u16 = 0x0008;
+
+pub const INTERNAL_SYSTEM_TICK_EVENT_CODE: u16 = 0x0009;
+
+pub const PROGRAMMER_START_EVENT_PROCESSOR_UPLOAD_EVENT_CODE: u16 = 0x000a;
